Crate llcio

Crate llcio 

Functions

boolput
A function to get boolean input from the user with a prompt
floatput
A function to get floating-point input from the user with a prompt
input
A basic function to read a line of input from the user
intput
A function to get integer input from the user with a prompt
strinput
A function to get string input from the user with a prompt